//
//  'MonoView' image/video wallpaper for BeOS.
//  Copyright (C) 1999, 2000
//  Okada Jun (yun@be-in.org)
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  MonoView is yet another wallpaper running on BeOS Intel and PPC,
//  originally designed and developed by Okada Jun in 1999.
//  http://www.be-in.org/~yun/
//


#include <Looper.h>
#include <Bitmap.h>
#include <Region.h>
#include <MessageQueue.h>

#include "MVControlView.h"
#include "MVControlState.h"


MVControlState::MVControlState(void)
{
}


void
MVControlState::AllAttached(MVControlView *view)
{
  view->MVReplicantableView::AllAttached();
}


void
MVControlState::AllDetached(MVControlView *view)
{
  view->MVReplicantableView::AllDetached();
}


void
MVControlState::FrameResized(MVControlView *view,
			     float width, float height)
{
}


void
MVControlState::Draw(MVControlView *view,
		     BRect updateRect)
{
  BRect dstFrame(0.0,
  		 0.0,
		 int(view->mBitmap->Bounds().Width() * view->mMagnification),
		 int(view->mBitmap->Bounds().Height() * view->mMagnification));
  dstFrame.OffsetBy(view->mOffset);
  BRegion bounds;
  bounds.Set(view->Bounds());
  bounds.Exclude(dstFrame);
  view->SetHighColor(0, 0, 0);
  view->FillRegion(&bounds);

  view->DrawBitmap(view->mBitmap, dstFrame);
  
  view->MVReplicantableView::Draw(updateRect);
}


void
MVControlState::KeyDown(MVControlView *view, 
	const char *bytes, int32 numBytes)
{
  view->BView::KeyDown(bytes, numBytes);
}


void
MVControlState::MouseDown(MVControlView *view,
			  BPoint point)
{
  view->SetMouseEventMask(B_POINTER_EVENTS);
  view->mIsMouseHolding = true;
  view->mPrevMouse = point;
}


void
MVControlState::MouseMoved(MVControlView *view, 
			   BPoint point, uint32 transit, const BMessage *msg)

{
  if (view->mIsMouseHolding)
    {
      BMessage *mouseMovedMsg;
      
      while ((mouseMovedMsg = 
	      view->Looper()->MessageQueue()->FindMessage(B_MOUSE_MOVED, 0)))
	{
	  view->Looper()->MessageQueue()->RemoveMessage(mouseMovedMsg);
	  delete mouseMovedMsg;
	}

      uint32 buttons;
      view->GetMouse(&point, &buttons, false);
      view->mOffset += point - view->mPrevMouse;
      view->mPrevMouse = point;
      view->InscribedToFrame();
      view->Invalidate();
    }
}


void
MVControlState::MouseUp(MVControlView *view,
			BPoint point)
{
  view->mIsMouseHolding = false;
}


void
MVControlState::MessageReceived(MVControlView *view, 
		     BMessage *msg)
{
  view->MVReplicantableView::MessageReceived(msg);
}
