//
//  'MonoView' image/video wallpaper for BeOS.
//  Copyright (C) 1999, 2000
//  Okada Jun (yun@be-in.org)
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  MonoView is yet another wallpaper running on BeOS Intel and PPC,
//  originally designed and developed by Okada Jun in 1999.
//  http://www.be-in.org/~yun/
//


#ifndef MV_CONTROL_VIEW_H
#define MV_CONTROL_VIEW_H


#include <Entry.h>

#include "MVReplicantableView.h"


class BBitmap;
class MVControlState;


class MVControlView : public MVReplicantableView
{
public:
  MVControlView(const entry_ref &ref);
  MVControlView(BMessage *archive);
  virtual ~MVControlView(void);
  virtual status_t Archive(BMessage *archive, bool deep = true) const;

  virtual status_t InitCheck(void) = 0;
  const char *FileName(void) const;

  friend class MVControlState;
  friend class MVControlApplicationState;
  friend class MVControlReplicantState;
  friend class MVControlNullState;

protected:
  virtual void Draw(BRect updateRect);
  virtual void AllAttached(void);
  virtual void AllDetached(void);
  virtual void KeyDown(const char *bytes, int32 numBytes);
  virtual void MouseDown(BPoint point);
  virtual void MouseUp(BPoint point);
  virtual void MouseMoved(BPoint point, uint32 transit, const BMessage *msg);
  virtual void FrameResized(float width, float height);
  virtual void MessageReceived(BMessage *msg);

  entry_ref mRef;
  BBitmap *mBitmap;
  MVControlState *mState;

private:
  void ChangeMagnification(float magnification);
  void InscribedToFrame(void);
  void FitToScreen(void);
  void SetTitle(void);

  void StartNodeMonitoring(void);
  void PursuitNode(const BMessage *msg);
  void EndNodeMonitoring(void);

  BPoint mOffset;
  float mMagnification;

  bool mIgnoreResize;

  BPoint mPrevMouse;
  bool mIsMouseHolding;
};


#endif
