//
//  'MonoView' image/video wallpaper for BeOS.
//  Copyright (C) 1999, 2000
//  Okada Jun (yun@be-in.org)
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  MonoView is yet another wallpaper running on BeOS Intel and PPC,
//  originally designed and developed by Okada Jun in 1999.
//  http://www.be-in.org/~yun/
//


#include <Bitmap.h>
#include <File.h>
#include <TranslationUtils.h>
#include <Message.h>

#include "MVDefs.h"
#include "MVControlNullState.h"
#include "MVImageView.h"


MVImageView::MVImageView(const entry_ref &ref)
  : MVControlView(ref)
{
  BFile file(&ref, B_READ_ONLY);
  mBitmap = BTranslationUtils::GetBitmap(&file);
  if (mBitmap)
    {
      mInitStatus = B_OK;
      this->ResizeTo(mBitmap->Bounds().Width(), mBitmap->Bounds().Height());
    }
  else
    mInitStatus = B_ERROR;
}


MVImageView::MVImageView(BMessage *archive)
  : MVControlView(archive)
{
  BFile file(&mRef, B_READ_ONLY);
  mBitmap = BTranslationUtils::GetBitmap(&file);
  if (! mBitmap)
    mState = MVControlNullState::Instance();
}


status_t
MVImageView::Archive(BMessage *msg, bool deep) const
{
  msg->AddString("add_on", MV_SIGNATURE);
    
  return MVControlView::Archive(msg, deep);
}


BArchivable *
MVImageView::Instantiate(BMessage *archive)
{
  if (validate_instantiation(archive, "MVImageView"))
    return new MVImageView(archive);

  return NULL;
}


MVImageView::~MVImageView(void)
{
  if (mBitmap)
    delete mBitmap;
}


status_t
MVImageView::InitCheck(void)
{
  return mInitStatus;
}


