//
//  'MonoView' image/video wallpaper for BeOS.
//  Copyright (C) 1999, 2000
//  Okada Jun (yun@be-in.org)
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//  MonoView is yet another wallpaper running on BeOS Intel and PPC,
//  originally designed and developed by Okada Jun in 1999.
//  http://www.be-in.org/~yun/
//


#include <cstdio>

#include <MenuItem.h>

#include "MVDefs.h"
#include "MVWorkspaceMenu.h"


MVWorkspaceMenu::MVWorkspaceMenu(const char *name, int32 workspace)
  : BMenu(name)
{
  this->SetRadioMode(true);
  this->InitItems();
  this->SetWorkspace(workspace);
}

MVWorkspaceMenu::MVWorkspaceMenu(BMessage *archive)
  : BMenu(archive)
{
}

BArchivable *
MVWorkspaceMenu::Instantiate(BMessage *archive)
{
  if (validate_instantiation(archive, "MVWorkspaceMenu"))
    return new MVWorkspaceMenu(archive);

  return NULL;
}

status_t
MVWorkspaceMenu::Archive(BMessage *archive, bool deep) const
{
  archive->AddString("add_on", MV_SIGNATURE);

  return BMenu::Archive(archive, deep);
}


MVWorkspaceMenu::~MVWorkspaceMenu(void)
{
}


void
MVWorkspaceMenu::SetTarget(BHandler *target)
{
  mTarget = target;
}


int32
MVWorkspaceMenu::Workspace(void)
{
  return this->IndexOf(this->FindMarked()) - 1;
}


void
MVWorkspaceMenu::SetWorkspace(int32 workspace)
{
  this->ItemAt(workspace + 1)->SetMarked(true);
}


void
MVWorkspaceMenu::UpdateItems(void)
{
  int workspace;

  workspace = this->Workspace();
  this->InitItems();
  this->SetWorkspace(workspace);
}


void
MVWorkspaceMenu::InitItems(void)
{
  BMessage msg(MV_SET_WORKSPACE);
  char buf[3];
  int i;

  while (this->CountItems())
    this->RemoveItem((int32)0);
  
  msg.AddInt32("workspace", B_ALL_WORKSPACES);
  this->AddItem(new BMenuItem("All Workspaces", new BMessage(msg)));
  
  for (i = 0; i < count_workspaces(); i++)
    {
      msg.ReplaceInt32("workspace", i);
      sprintf(buf, "%2d", i + 1);
      this->AddItem(new BMenuItem(buf, new BMessage(msg)));
    }
}



bool
MVWorkspaceMenu::AddDynamicItem(add_state s)
{
  switch (s)
    {
    case B_INITIAL_ADD:
      {
	if (this->CountItems() != count_workspaces() + 1)
	  this->UpdateItems();
	this->SetTargetForItems(mTarget);
	
	return false;
      }

    default:
      return false;
    }
}  
